/************************************************************************/
/*  External variables for msextract.					*/
/*									*/
/*	Douglas Neuhauser						*/
/*	Berkeley Seismological Laboratory				*/
/*	University of California, Berkeley				*/
/*	doug@seismo.berkeley.edu					*/
/*									*/
/************************************************************************/

/*
 * Copyright (c) 1996-2000 The Regents of the University of California.
 * All Rights Reserved.
 * 
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for educational, research and non-profit purposes,
 * without fee, and without a written agreement is hereby granted,
 * provided that the above copyright notice, this paragraph and the
 * following three paragraphs appear in all copies.
 * 
 * Permission to incorporate this software into commercial products may
 * be obtained from the Office of Technology Licensing, 2150 Shattuck
 * Avenue, Suite 510, Berkeley, CA  94704.
 * 
 * IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY
 * FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES,
 * INCLUDING LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND
 * ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF CALIFORNIA HAS BEEN
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE
 * PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF
 * CALIFORNIA HAS NO OBLIGATIONS TO PROVIDE MAINTENANCE, SUPPORT,
 * UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 */

/*	$Id: externals.h,v 1.3 2003/10/29 21:17:28 lombard Exp $ 	*/

#include <qlib2.h>
#include "polygon.h"

typedef struct _event {
	INT_TIME	time;	/* time of event.			*/
        VERTEX		loc;	/* location of event - lat, long	*/
	double		depth;	/* location of event - depth (km).	*/
	double		mag;	/* magnitude of event.			*/
} EVENT;

typedef struct _window {
    INT_TIME		start;	/* start time of window			*/
    INT_TIME    	end;	/* end time of window			*/
    EVENT		*event;	/* pointer to event of this window;	*
				 * NULL for the box window		*/
} WINDOW;


char *cmdname;			/* program name.			*/
char *input_file;		/* input file name.			*/
char *output_file;		/* output file name.			*/
char *event_file;		/* event file name.			*/
char *box_file;			/* box file name.			*/
char *coord_file;		/* station coordinate file name.	*/
FILE *info;			/* FILE for informational msgs.		*/
int date_fmt;			/* key for output date format.		*/
int pre_p;			/* pre P-wave time to keep (seconds).	*/
int post_s;			/* post S-wave time to keep (seconds).	*/
int pre_origin;			/* pre origin time to keep (seconds).	*/
int origin_duration;		/* time from pre-origin to keep.	*/
int debug_option;		/* debug option flag.			*/
char *window_selection;		/* window selection criteria.		*/
extern char *syntax[];		/* syntax info.				*/

#define	DEBUG
#define	DEBUG_WINDOW		1
#define	DEBUG_DATA_SAVE		2
#define	DEBUG_DATA_REJECT	4
#define	DEBUG_ANY	\
    (DEBUG_WINDOW | DEBUG_DATA)
#define	    debug(val)  (debug_option & (val))
